@@ -86,6 +86,7 @@ class Compiler(object):
     def __init__(
             self, root=Path(), search_path=(),
             namespace=None, extensions=(CoreExtension,),
+            import_static_css=False,
             output_style='nested', generate_source_map=False,
             live_errors=False, warn_unused_imports=False,
             ignore_parse_errors=False,
@@ -137,6 +138,13 @@ class Compiler(object):
                     .format(extension)
                 )
 
+        if import_static_css:
+            self.dynamic_extensions = ('.scss', '.sass', '.css')
+            self.static_extensions = ()
+        else:
+            self.dynamic_extensions = ('.scss', '.sass')
+            self.static_extensions = ('.css',)
+
         self.output_style = output_style
         self.generate_source_map = generate_source_map
         self.live_errors = live_errors
@@ -187,6 +195,14 @@ class Compiler(object):
             compilation.add_source(source)
         return self.call_and_catch_errors(compilation.run)
 
+    def compile_sources(self, *sources):
+        # TODO this api is not the best please don't use it.  this all needs to
+        # be vastly simplified, still, somehow.
+        compilation = self.make_compilation()
+        for source in sources:
+            compilation.add_source(source)
+        return self.call_and_catch_errors(compilation.run)
+
     def compile_string(self, string):
         source = SourceFile.from_string(string)
         compilation = self.make_compilation()
@@ -827,7 +843,7 @@ class Compilation(object):
                     # If the filename begins with an http protocol
                     sass_path.value.startswith(('http://', 'https://')) or
                     # If the filename ends with .css
-                    sass_path.value.endswith('.css')):
+                    sass_path.value.endswith(self.compiler.static_extensions)):
                 css_imports.append(sass_path.render(compress=False))
                 continue
 
